==> advent-of-code-py-0.1.0.tar.gz: advent-of-code-py-0.1.0/advent_of_code_py/initializer.py <==
"""
initializer module which defines Initializer class for initializing advent of code
function runner
"""
import inspect


class Initializer:
    """
    Initialize class which is used to initialize an advent of code function runner.
    Initialize create out a basic class which is used for adding of different
    function of advent of code solution so all of functions can be easily run with
    one simple CLI tool.
    """

    function_list = {}

    def add(self, **kwargs):
        """Add a function to a Initializer class"""
        self.function_list.update(kwargs)

    def extend(self, another_initializer):
        """Extends initializer with addition of another initialier to it"""
        for (keys, value) in another_initializer.get_function_list().items():
            self.function_list.update(keys=value)

    def run(self, function_alias: str):
        """Run a certain function by their name/alias"""
        self.function_list.get(function_alias)()

    def run_all(self):
        """Run all functions which are added to `Initializer`"""
        for value in self.function_list.values():
            value()

    def list_functions(self):
        """List out all of the function and its location along with its alias"""
        for (keys, value) in self.function_list.items():
            print(
                "{:10} -> {}.{}".format(
                    keys, inspect.getmodule(value).__name__, value.__name__
                )
            )

    def get_function_list(self):
        """Return out all function_list which contain function_alias and function"""
        return self.function_list

==> advent-of-code-py-0.1.2.tar.gz: advent-of-code-py-0.1.2/advent_of_code_py/initializer.py <==
"""
initializer module which defines Initializer class for initializing advent of code
function runner
"""
import inspect


class Initializer:
    """
    Initialize class which is used to initialize an advent of code function runner.
    Initialize create out a basic class which is used for adding of different
    function of advent of code solution so all of functions can be easily run with
    one simple CLI tool.
    """

    function_list = {}

    def add(self, **kwargs):
        """Add a function to a Initializer class"""
        self.function_list.update(kwargs)

    def extend(self, another_initializer):
        """Extends initializer with addition of another initialier to it"""
        self.function_list.update(another_initializer)

    def run(self, function_alias: str):
        """Run a certain function by their name/alias"""
        self.function_list.get(function_alias)()

    def run_all(self):
        """Run all functions which are added to `Initializer`"""
        for value in self.function_list.values():
            value()

    def list_functions(self):
        """List out all of the function and its location along with its alias"""
        for (keys, value) in self.function_list.items():
            print(
                "{:10} -> {}.{}".format(
                    keys, inspect.getmodule(value).__name__, value.__name__
                )
            )

    def get_function_list(self):
        """Return out all function_list which contain function_alias and function"""
        return self.function_list
